# Reference

Complete technical reference for erk commands, configuration, and file locations.

Reference documentation is **information-oriented**. It provides accurate, complete descriptions of erk's interfaces.

## Contents

### Commands

- [CLI Command Reference](commands.md) - All CLI commands and their options
- [Slash Command Reference](slash-commands.md) - Claude Code slash commands for in-session use

### Configuration

- [Configuration Reference](configuration.md) - Config files and options
- [File Location Reference](file-locations.md) - Where erk stores data and configuration
